import React, { Component } from 'react';
import { View, TouchableWithoutFeedback, Text, Alert, Image } from 'react-native';
import PropTypes from 'prop-types';
import { ImagePicker } from 'expo';
import { EvilIcons } from '@expo/vector-icons';

import Utils from './Utils';

export default class ImageFrame extends Component {
  static propTypes = {
    onChange: PropTypes.func,
    name: PropTypes.string,
    label: PropTypes.string,
    labelColor: PropTypes.string,
    labelFontSize: PropTypes.number,
    aspectRatio: PropTypes.number,
    borderRadius: PropTypes.number,
    borderColor: PropTypes.string,
    quality: PropTypes.number,
    url: PropTypes.string
  };

  static defaultProps = {
    onChange: () => {},
    name: '',
    label: '',
    labelColor: '#1d1d1d',
    labelFontSize: 16,
    aspectRatio: 1,
    borderRadius: 1,
    borderColor: '#cfcfcf',
    quality: 0.7,
    url: ''
  };

  state = {
    url: this.props.url
  };

  componentWillReceiveProps(nextProps) {
    this.setState({
      url: nextProps.url
    });
  }

  onPressAddingImage = async () => {
    const result = await ImagePicker.launchImageLibraryAsync({
      allowsEditing: true,
      aspect: [this.props.aspectRatio * 10, 10],
      quality: this.props.quality,
      base64: true
    });

    if (!result.cancelled) {
      Utils.uploadImage(result.base64, (error, url) => {
        if (error) {
          Alert.alert('Fail to upload image.', error.reason, [{ text: '확인' }]);

          return;
        }

        setTimeout(() => {
          this.props.onChange(url, this.props.name);

          this.setState({
            url: url
          });
        }, 1000);
      });
    }
  };

  onPressDeletingImage = () => {
    this.props.onChange('', this.props.name);

    this.setState({
      url: ''
    });
  };

  render() {
    return (
      <View>
        { !this.state.url &&
          <TouchableWithoutFeedback onPress={this.onPressAddingImage}>
            <View style={{
              aspectRatio: this.props.aspectRatio,
              borderWidth: 1,
              borderColor: this.props.borderColor,
              borderStyle: 'dashed',
              borderRadius: this.props.borderRadius,
              alignItems: 'center',
              justifyContent: 'center'
            }}
            >
              <View style={{
                width: 1,
                height: 36,
                position: 'absolute',
                top: '50%',
                left: '50%',
                backgroundColor: this.props.borderColor,
                transform: [{ translateY: -18 }] }}
              />
              <View style={{
                width: 36,
                height: 1,
                position: 'absolute',
                top: '50%',
                left: '50%',
                backgroundColor: this.props.borderColor,
                transform: [{ translateX: -18 }] }}
              />
            </View>
          </TouchableWithoutFeedback>
        }
        { !!this.state.url &&
          <View style={{ aspectRatio: this.props.aspectRatio }}>
            <Image source={{ uri: this.state.url }} style={{ width: '100%', aspectRatio: this.props.aspectRatio }} />
            <TouchableWithoutFeedback onPress={this.onPressDeletingImage}>
              <View style={{ position: 'absolute', top: 0, right: 0, width: 35, height: 35, backgroundColor: 'rgba(0, 0, 0, 0.2)', justifyContent: 'center', alignItems: 'center' }}>
                <EvilIcons name="close" color="#fcfcfc" size={35} />
              </View>
            </TouchableWithoutFeedback>
          </View>
        }
        { !!this.props.label &&
          <Text style={{ textAlign: 'center', marginTop: 10, color: this.props.labelColor, fontSize: this.props.labelFontSize }}>{ this.props.label }</Text>
        }
      </View>
    );
  }
}
