import Meteor, { Accounts } from 'react-native-meteor';
import moment from 'moment';
import { Alert } from 'react-native';
import { Notifications } from 'expo';
import { NavigationActions } from 'react-navigation';

export default class Utils {
  static getFormattedPrice = (amount, unit = '원') => {
    return parseInt(amount).toString().replace(/\B(?=(\d{3})+(?!\d))/g, ',') + unit;
  };

  static getFormattedDate = (date) => {
    if (moment().diff(moment(date), 'days') < 5) {
      return moment(date).fromNow();
    }
    else {
      return moment(date).format('YYYY-MM-DD HH:mm');
    }
  };

  static sendSms = (phoneNumber, message) => {
    return Meteor.call('sendSms', phoneNumber, message);
  };

  static sendRemoteNotification = (to, title, content) => {
    return Meteor.call('sendRemoteNotification', to, title, content);
  };

  static uploadImage = (data, callback) => {
    Meteor.call('uploadImage', data, (error, result) => {
      callback(error, result);
    });
  };

  static createUser = (options, callback) => {
    Accounts.createUser(options, (error) => {
      if (error) {
        if (error.reason == 'Email already exists.') {
          error.reason = '이미 존재하는 이메일입니다.';
        }
      }

      callback(error);
    });
  };

  static signIn = (email, password, callback) => {
    Meteor.loginWithPassword(email, password, async (error) => {
      if (error) {
        if (error.reason == 'User not found') {
          error.reason = '존재하지 않는 이메일입니다.';
        }
        else if (error.reason == 'Incorrect password') {
          error.reason = '비밀번호가 틀립니다.';
        }

        callback(error);

        return;
      }

      if (!Meteor.user().profile.isActive) {
        Meteor.logout();

        const error = {
          reason: '정지된 계정입니다.'
        };

        callback(error);

        return;
      }

      const notificationToken = await Notifications.getExpoPushTokenAsync();

      Meteor.call('users.addToSetNotificationToken', notificationToken, (error) => {
        callback(error);
      });
    });
  };

  static reset = (navigation, to) => {
    const resetAction = NavigationActions.reset({
      index: 0,
      actions: [
        NavigationActions.navigate({
          routeName: to
        })
      ]
    });

    navigation.dispatch(resetAction);
  };
}
